Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Amplify.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS Amplify - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Amplify

AWS Amplify (service prefix: `amplify` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Amplify
- Resource Types Defined by AWS Amplify
- Condition Keys for AWS Amplify

## Actions Defined by AWS Amplify

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateApp | Creates a new Amplify App. | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateBackendEnvironment | Creates a new backend environment for an Amplify App. | Write | apps* |  |
CreateBranch | Creates a new Branch for an Amplify App. | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDeployment | Create a deployment for manual deploy apps. (Apps are not connected to repository) | Write | branches* |  |
CreateDomainAssociation | Create a new DomainAssociation on an App | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWebHook | Create a new webhook on an App. | Write | branches* |  |
DeleteApp | Delete an existing Amplify App by appId. | Write | apps* |  |
DeleteBackendEnvironment | Deletes a branch for an Amplify App. | Write | apps* |  |
DeleteBranch | Deletes a branch for an Amplify App. | Write | branches* |  |
DeleteDomainAssociation | Deletes a DomainAssociation. | Write | domains* |  |
DeleteJob | Delete a job, for an Amplify branch, part of Amplify App. | Write | jobs* |  |
DeleteWebHook | Delete a webhook by id. | Write | apps* |  |
GenerateAccessLogs | Generate website access logs for a specific time range via a pre-signed URL. | Write | apps* |  |
GetApp | Retrieves an existing Amplify App by appId. | Read | apps* |  |
GetArtifactUrl | Retrieves artifact info that corresponds to a artifactId. | Read | apps* |  |
GetBackendEnvironment | Retrieves a backend environment for an Amplify App. | Read | apps* |  |
GetBranch | Retrieves a branch for an Amplify App. | Read | branches* |  |
GetDomainAssociation | Retrieves domain info that corresponds to an appId and domainName. | Read | domains* |  |
GetJob | Get a job for a branch, part of an Amplify App. | Read | jobs* |  |
GetWebHook | Retrieves webhook info that corresponds to a webhookId. | Read | apps* |  |
ListApps | Lists existing Amplify Apps. | List |  |  |
ListArtifacts | List artifacts with an app, a branch, a job and an artifact type. | List | apps* |  |
ListBackendEnvironments | Lists backend environments for an Amplify App. | List | apps* |  |
ListBranches | Lists branches for an Amplify App. | List | apps* |  |
ListDomainAssociations | List domains with an app | List | apps* |  |
ListJobs | List Jobs for a branch, part of an Amplify App. | List | branches* |  |
ListWebHooks | List webhooks on an App. | List | apps* |  |
StartDeployment | Start a deployment for manual deploy apps. (Apps are not connected to repository) | Write | branches* |  |
StartJob | Starts a new job for a branch, part of an Amplify App. | Write | jobs* |  |
StopJob | Stop a job that is in progress, for an Amplify branch, part of Amplify App. | Write | jobs* |  |
TagResource | This action tags an AWS Amplify Console resource. | Tagging | apps |  |
branches |  |
jobs |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | This action removes a tag from an AWS Amplify Console resource. | Tagging | apps |  |
branches |  |
jobs |  |
| aws:TagKeys |
UpdateApp | Updates an existing Amplify App. | Write | apps* |  |
UpdateBranch | Updates a branch for an Amplify App. | Write | branches* |  |
UpdateDomainAssociation | Update a DomainAssociation on an App. | Write | domains* |  |
UpdateWebHook | Update a webhook. | Write | apps* |  |

## Resource Types Defined by AWS Amplify

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
apps | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}` | aws:ResourceTag/${TagKey}
branches | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/branches/$ { BranchName}` | aws:ResourceTag/${TagKey}
jobs | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/branches/$ { BranchName}/jobs/$ { JobId}` |
domains | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/domains/$ { DomainName}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS Amplify

AWS Amplify defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} |  | String
aws:ResourceTag/$ { TagKey} |  | String
aws:TagKeys |  | String